/* NSWindowStyleMask-test.m: NSWindow styleMasks test

   Copyright (C) 1999, 2000 Free Software Foundation, Inc.

   Author:  Nicola Pero <n.pero@mi.flashnet.it>
   Date: 1999, July 2000
   
   This file is part of GNUstep.
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#include <Foundation/Foundation.h>
#include <AppKit/AppKit.h>
#include <AppKit/GSHbox.h>
#include <AppKit/GSTable.h>
#include <AppKit/GSVbox.h>
#include "../GSTestProtocol.h"


@interface NSDrawerTest: NSObject <GSTest>
{
  NSDrawer *drawer;
  NSWindow *win;
  
  NSView *drawerContent;
  NSRectEdge _edge;
}
-(void) setupGUI;
-(void) restart;
-(void) toggleDrawer: (id)sender;
@end

@implementation NSDrawerTest: NSObject
{
  // for instance variables see above
}
-(id) init
{
    [self setupGUI];

    [self restart];
    return self;
}

- (void) setupGUI
{
  // setup content view of nsdrawer
  drawerContent = [[NSView alloc] init];
  [drawerContent setBoundsSize: NSMakeSize(100, 100)];

  _edge = NSMinXEdge;

    
  // mainView
  GSVbox *contentBox;
  
  // button to open one drawer
  NSButton *top;
  
  contentBox = AUTORELEASE( [GSVbox new]);
  
  top = [[NSButton alloc] init];
  [top setButtonType: NSPushOnPushOffButton];
  [top setTarget: self];
  [top setAction: @selector (toggleDrawer:)];

  [contentBox addView: top];
  
  NSRect winFrame;
  winFrame.size = NSMakeSize(500,500); //[contentBox frame].size;
  winFrame.origin = NSMakePoint( 100, 100 );

  win = [[NSWindow alloc] initWithContentRect: winFrame
			  styleMask: (NSTitledWindowMask 
				      | NSClosableWindowMask 
				      | NSMiniaturizableWindowMask)
			  backing: NSBackingStoreBuffered
			  defer: NO];
  [win setReleasedWhenClosed: NO];  
  [win setContentView: top];
  [win setTitle: @"NSDrawer Test"];
}

-(void) dealloc
{
  RELEASE (win);
  [super dealloc];
}
-(void) restart
{
    [win orderFront: nil];
    [[NSApplication sharedApplication] addWindowsItem: win
                                     title: @"NSDrawer Test"
                                     filename: NO];
}


// perform the work ;))
-(void) toggleDrawer: (id) sender 
{
  if ( drawer == nil )
  {
      NSLog( @"creating drawer...");
      drawer = [NSDrawer alloc];
      [drawer initWithContentSize: [drawerContent bounds].size preferredEdge: _edge];
      [drawer setParentWindow: win];
  }
  NSLog( @"toggle drawer now!");
  [drawer toggle: sender];
}
@end
